@@ -20,11 +20,14 @@ import numbers
 from collections import defaultdict, namedtuple
 import threading
 
+
 class pyy_tag(object):
   TAB = '  '
 
-  is_single = False #Tag does not require matching end tag (ex. <hr/>)
-  is_pretty = True  #Text inside the tag should be left as-is (ex. <pre>)
+  is_single = False  # Tag does not require matching end tag (ex. <hr/>)
+  is_pretty = True   # Text inside the tag should be left as-is (ex. <pre>)
+                     # otherwise, text will be escaped() and whitespace may be
+                     # modified
 
   frame = namedtuple('frame', ['tag', 'items', 'used'])
 
@@ -106,6 +109,8 @@ class pyy_tag(object):
         obj = str(obj)
 
       if isinstance(obj, basestring):
+        if self.is_pretty:
+          obj = escape(obj)
         self.children.append(obj)
 
       elif isinstance(obj, pyy_tag):
@@ -116,7 +121,6 @@ class pyy_tag(object):
         obj.parent = self
         obj.setdocument(self.document)
 
-
       elif isinstance(obj, dict):
         for attr, value in obj.items():
           self.set_attribute(*pyy_tag.clean_pair(attr, value))
@@ -125,7 +129,7 @@ class pyy_tag(object):
         for subobj in obj:
           self.add(subobj)
 
-      else: # wtf is it?
+      else:  # wtf is it?
         raise ValueError('%r not a tag or string.' % obj)
 
 
@@ -134,6 +138,9 @@ class pyy_tag(object):
 
     return args
 
+  def add_raw_string(self, s):
+    self.children.append(s)
+
   def clear(self):
     for i in self.children:
       if isinstance(i, pyy_tag) and i.parent is self:
